==> kita-0.3.tar.gz: kita-0.3/kita/src/part/kitathreadpart.cpp <==

#include "kitathreadpart.h"

#include <kio/job.h>
#include <khtml_part.h>

//static const char * version = $VERSION$;
static const char * version = "1.0";

typedef KParts::GenericFactory<KitaThreadPart> KitaThreadFactory;
 K_EXPORT_COMPONENT_FACTORY( libkitapart, KitaThreadFactory );

KAboutData * KitaThreadPart::createAboutData() // needed by GenericFactory
{
    KAboutData * about = new KAboutData( 
	    "kitapart", 
	    I18N_NOOP("Kitapart plug-in"), 
	    version, 
	    "2ch thread dat viewer plugin.", 
	    KAboutData::License_GPL, 
	    "(C) 2003 Konqueror-plugin no hito, (C) 2001 Hideki Ikemoto",
	    "http://pc.2ch.net/linux/",
	    "no-mail"
	    );
    about->addAuthor( "Hideki Ikemoto", "Initial widget writer", "ikemo@wakaba.jp", 0 );
    about->addAuthor( "Konqueror-plugin no hito", "Kparts & some hacks.", 0, "http://pc.2ch.net/linux" );
    return about; // will be passed to GenericFactory.
}

KitaThreadPart::KitaThreadPart(  QWidget *parentWidget, const char *, QObject *parent, const char *name, const QStringList& )
  : KParts::ReadOnlyPart( parent, name )
  , m_threadview( 0 )
  , m_extension( 0 )
{
    m_threadview = new KitaThreadView( parentWidget ); // auto delete
    setInstance( KitaThreadFactory::instance() );
    setWidget( m_threadview );

    m_extension = new KitaThreadBrowserExtension( this );
    m_threadview->show();

    connect( m_threadview, SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ), 
	      m_extension, SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ) );
    connect( m_threadview, SIGNAL( createNewWindow (const KURL&, const KParts::URLArgs&) ),
	      m_extension, SIGNAL( createNewWindow (const KURL&, const KParts::URLArgs&) ) );
    connect( m_threadview, SIGNAL( setLocationBarURL(const QString &) ),
	      m_extension, SIGNAL( setLocationBarURL(const QString &) ) );
    connect( m_threadview, SIGNAL( enableAction(const char*, bool) ),
	      m_extension, SIGNAL( enableAction(const char*, bool) ) ); 
    //connect( m_threadview, SIGNAL( signalChangeStatusbar(const QString&) ),
//	      m_extension, SIGNAL( infoMessage(const QString&) ) );
    //popupMenu
#if 0
    connect( m_threadview->threadPart->browserExtension(),
	      SIGNAL(popupMenu(const QPoint &, const KFileItemList&)),
	     m_extension, SIGNAL(popupMenu(const QPoint&, const KFileItemList &)) );
    connect( m_threadview->threadPart->browserExtension(),
	      SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KFileItemList&)),
	     m_extension, SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KFileItemList &)) );
    connect( m_threadview->threadPart->browserExtension(),
	      SIGNAL(popupMenu(const QPoint&, const KURL&, const QString&, mode_t)),
	     m_extension, SIGNAL(popupMenu(const QPoint&, const KURL&, const QString&, mode_t)) );
#endif
    connect( m_threadview, SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KURL&, const QString&, mode_t)),
	      m_extension, SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KURL&, const QString&, mode_t)) );
    KParts::BrowserExtension * ext;
    ext = m_threadview->m_threadPart->browserExtension();
    connect( ext, SIGNAL(infoMessage(const QString&)),
	      m_extension, SIGNAL(infoMessage(const QString&)) ); 
    connect( ext, SIGNAL(selectionInfo(const KURL::List&)),
	      m_extension, SIGNAL(selectionInfo(const KURL::List&)) );
    connect( ext, SIGNAL(selectionInfo(const QString&)),
	      m_extension, SIGNAL(selectionInfo(const QString&)) );
    connect( ext, SIGNAL(selectionInfo(const KFileItemList&)),
	      m_extension, SIGNAL(selectionInfo(const KFileItemList&)) );
}

KitaThreadPart::~KitaThreadPart()
{
    closeURL();
    if ( m_extension ) {
	delete m_extension;
	m_extension = 0;
    }
}

KParts::BrowserExtension * KitaThreadPart::browserExtension() const
{
    return m_extension;
}

bool KitaThreadPart::openURL( const KURL& _url )
{
    printf("  KitaThreadPart::openURL _url: %s\n", _url.url().latin1() );
    m_url = _url;
    emit setWindowCaption( m_url.url() );
    connect( m_threadview, SIGNAL( showThreadCompleted() ),
	     this, SLOT( slotOpenURLResult() ) );
    m_threadview->slotShowThread( m_url, m_url.upURL().upURL() );
    emit started( 0 );
    return true;
}

bool KitaThreadPart::closeURL()
{
    if ( m_threadview->m_currentJob ) {
	m_threadview->m_currentJob->kill();
    }
    return true;
}

void KitaThreadPart::slotOpenURLResult()
{
    disconnect( m_threadview, SIGNAL( showThreadCompleted() ),
	     this, SLOT( slotOpenURLResult() ) );
    emit setWindowCaption( m_threadview->threadSubject() );
    emit completed();
}

void KitaThreadPart::guiActivateEvent ( KParts::GUIActivateEvent *event )
{
    //KParts::ReadOnlyPart::guiActivateEvent( event );
    if ( event->activated() )
        emit setWindowCaption( m_threadview->threadSubject() );
}

KitaThreadBrowserExtension::KitaThreadBrowserExtension( KitaThreadPart * parent )
  : KParts::BrowserExtension( parent, "KitaThreadBrowserExtension" )
{
    // DND Drop enable: 1st stage. 
    setURLDropHandlingEnabled( true ); // default: false
}

KitaThreadBrowserExtension::~KitaThreadBrowserExtension()
{
}

// vim:sw=4:

==> kita-0.4.tar.gz: kita-0.4/kita/src/part/kitathreadpart.cpp <==

#include "kitathreadpart.h"

#include <kio/job.h>
#include <khtml_part.h>

#include "kitahtmlpart.h"

//static const char * version = $VERSION$;
static const char * version = "1.0";

typedef KParts::GenericFactory<KitaThreadPart> KitaThreadFactory;
 K_EXPORT_COMPONENT_FACTORY( libkitapart, KitaThreadFactory );

KAboutData * KitaThreadPart::createAboutData() // needed by GenericFactory
{
    KAboutData * about = new KAboutData( 
	    "kitapart", 
	    I18N_NOOP("Kitapart plug-in"), 
	    version, 
	    "2ch thread dat viewer plugin.", 
	    KAboutData::License_GPL, 
	    "(C) 2003 Konqueror-plugin no hito, (C) 2001 Hideki Ikemoto",
	    "http://pc.2ch.net/linux/",
	    "no-mail"
	    );
    about->addAuthor( "Hideki Ikemoto", "Initial widget writer", "ikemo@wakaba.jp", 0 );
    about->addAuthor( "Konqueror-plugin no hito", "Kparts & some hacks.", 0, "http://pc.2ch.net/linux" );
    return about; // will be passed to GenericFactory.
}

KitaThreadPart::KitaThreadPart(  QWidget *parentWidget, const char *, QObject *parent, const char *name, const QStringList& )
  : KParts::ReadOnlyPart( parent, name )
  , m_threadview( 0 )
  , m_extension( 0 )
{
    m_threadview = new KitaThreadView( parentWidget ); // auto delete
    setInstance( KitaThreadFactory::instance() );
    setWidget( m_threadview );

    m_extension = new KitaThreadBrowserExtension( this );
    m_threadview->show();

    connect( m_threadview, SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ), 
	      m_extension, SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ) );
    connect( m_threadview, SIGNAL( createNewWindow (const KURL&, const KParts::URLArgs&) ),
	      m_extension, SIGNAL( createNewWindow (const KURL&, const KParts::URLArgs&) ) );
    connect( m_threadview, SIGNAL( setLocationBarURL(const QString &) ),
	      m_extension, SIGNAL( setLocationBarURL(const QString &) ) );
    connect( m_threadview, SIGNAL( enableAction(const char*, bool) ),
	      m_extension, SIGNAL( enableAction(const char*, bool) ) ); 
    //connect( m_threadview, SIGNAL( signalChangeStatusbar(const QString&) ),
//	      m_extension, SIGNAL( infoMessage(const QString&) ) );
    //popupMenu
#if 0
    connect( m_threadview->threadPart->browserExtension(),
	      SIGNAL(popupMenu(const QPoint &, const KFileItemList&)),
	     m_extension, SIGNAL(popupMenu(const QPoint&, const KFileItemList &)) );
    connect( m_threadview->threadPart->browserExtension(),
	      SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KFileItemList&)),
	     m_extension, SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KFileItemList &)) );
    connect( m_threadview->threadPart->browserExtension(),
	      SIGNAL(popupMenu(const QPoint&, const KURL&, const QString&, mode_t)),
	     m_extension, SIGNAL(popupMenu(const QPoint&, const KURL&, const QString&, mode_t)) );
#endif
    connect( m_threadview, SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KURL&, const QString&, mode_t)),
	      m_extension, SIGNAL(popupMenu(KXMLGUIClient *, const QPoint&, const KURL&, const QString&, mode_t)) );
    KParts::BrowserExtension * ext;
    ext = m_threadview->m_threadPart->browserExtension();
    connect( ext, SIGNAL(infoMessage(const QString&)),
	      m_extension, SIGNAL(infoMessage(const QString&)) ); 
    connect( ext, SIGNAL(selectionInfo(const KURL::List&)),
	      m_extension, SIGNAL(selectionInfo(const KURL::List&)) );
    connect( ext, SIGNAL(selectionInfo(const QString&)),
	      m_extension, SIGNAL(selectionInfo(const QString&)) );
    connect( ext, SIGNAL(selectionInfo(const KFileItemList&)),
	      m_extension, SIGNAL(selectionInfo(const KFileItemList&)) );
}

KitaThreadPart::~KitaThreadPart()
{
    closeURL();
    if ( m_extension ) {
	delete m_extension;
	m_extension = 0;
    }
}

KParts::BrowserExtension * KitaThreadPart::browserExtension() const
{
    return m_extension;
}

bool KitaThreadPart::openURL( const KURL& _url )
{
    printf("  KitaThreadPart::openURL _url: %s\n", _url.url().latin1() );
    m_url = _url;
    emit setWindowCaption( m_url.url() );
    connect( m_threadview, SIGNAL( showThreadCompleted(const KURL&) ),
	     this, SLOT( slotOpenURLResult() ) );
    m_threadview->slotShowThread( Kita2ch::Board(m_url.upURL().upURL()) , Kita2ch::Thread(m_url) );
    emit started( 0 );
    return true;
}

bool KitaThreadPart::closeURL()
{
    if ( m_threadview->m_currentJob ) {
	m_threadview->m_currentJob->kill();
    }
    return true;
}

void KitaThreadPart::slotOpenURLResult()
{
    disconnect( m_threadview, SIGNAL( showThreadCompleted(const KURL&) ),
	     this, SLOT( slotOpenURLResult() ) );
    emit setWindowCaption( m_threadview->threadSubject() );
    emit completed();
}

void KitaThreadPart::guiActivateEvent ( KParts::GUIActivateEvent *event )
{
    //KParts::ReadOnlyPart::guiActivateEvent( event );
    if ( event->activated() )
        emit setWindowCaption( m_threadview->threadSubject() );
}

KitaThreadBrowserExtension::KitaThreadBrowserExtension( KitaThreadPart * parent )
  : KParts::BrowserExtension( parent, "KitaThreadBrowserExtension" )
{
    // DND Drop enable: 1st stage. 
    setURLDropHandlingEnabled( true ); // default: false
}

KitaThreadBrowserExtension::~KitaThreadBrowserExtension()
{
}

// vim:sw=4:
